
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.

-- Case insensitive searches
SET IGNORECASE TRUE;

-- Enforce length checks
SET PROPERTY "sql.enforce_strict_size" TRUE;


-- Internal table
-- Must be present
CREATE CACHED TABLE DBCATALOG40 (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    EV DATE NOT NULL,
    EV_DESC VARCHAR(255) NULL
);


-- Create main ReaderwareAW table
CREATE CACHED TABLE AUDIOWARE (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    TITLE VARCHAR(255) NOT NULL, 
    ARTIST BIGINT NULL, 
    ARTIST2 BIGINT NULL,
    ARTIST3 BIGINT NULL,
    ARTIST4 BIGINT NULL,
    ARTIST5 BIGINT NULL,
    ARTIST6 BIGINT NULL,
    COMPOSER BIGINT NULL, 
    CONDUCTOR BIGINT NULL, 
    ORCHESTRA BIGINT NULL, 
    SOLOIST BIGINT NULL, 
    WORK_TITLE VARCHAR(255) NULL, 
    PUBLISHER BIGINT NULL, 
    RELEASE_DATE DATE NULL, 
    COPYRIGHT_DATE DATE NULL, 
    RUNNING_TIME INTEGER NULL, 
    CONTENT_LANGUAGE BIGINT NULL, 
    COPIES INTEGER NOT NULL, 
    BARCODE VARCHAR(128) NULL, 
    UPC VARCHAR(25) NULL, 
    LCCN VARCHAR(16) NULL, 
    DEWEY VARCHAR(32) NULL, 
    CALL_NUMBER VARCHAR(32) NULL, 
    USER_NUMBER VARCHAR(32) NULL, 
    TYPE BIGINT NULL, 
    FORMAT BIGINT NULL,  
    SERIES BIGINT NULL, 
    SOUND BIGINT NULL, 
    MY_RATING BIGINT NULL, 
    ITEM_CONDITION BIGINT NULL, 
    COVER_CONDITION BIGINT NULL, 
    CATEGORY1 BIGINT NULL, 
    CATEGORY2 BIGINT NULL, 
    CATEGORY3 BIGINT NULL, 
    LOCATION BIGINT NULL, 
    KEYWORDS VARCHAR(255) NULL, 
    PLAYED_COUNT INTEGER NOT NULL, 
    DATE_LAST_PLAYED DATE NULL, 
    PLAYLIST BOOLEAN NOT NULL,
    PRODUCT_INFO VARCHAR(65536) NULL, 
    MY_COMMENTS VARCHAR(65536) NULL, 
    DATE_ENTERED DATE NOT NULL, 
    DATE_LAST_UPDATED DATE NOT NULL, 
    SOURCE BIGINT NULL, 
    CATALOG_NUMBER VARCHAR(50) NULL, 
    RECORDING_TYPE BIGINT NULL, 
    RECORDING_DATE DATE NULL, 
    RECORDING_PLACE VARCHAR(128) NULL, 
    PURCHASE_PRICE DECIMAL(12, 2) NOT NULL, 
    PURCHASE_DATE DATE NULL, 
    PURCHASE_PLACE BIGINT NULL, 
    LIST_PRICE DECIMAL(12, 2) NOT NULL, 
    ITEM_VALUE DECIMAL(12, 2) NOT NULL, 
    VALUATION_DATE DATE NULL, 
    CURRENCY_SYMBOL VARCHAR(5) NULL, 
    FAVORITE BOOLEAN NOT NULL,
    OUT_OF_PRINT BOOLEAN NOT NULL,
    MEDIA_URL VARCHAR(255) NULL, 
    OWNER BIGINT NULL,
    STATUS BIGINT NULL,
    EXTERNAL_ID VARCHAR(32) NULL, 
    INVENTORY INTEGER NOT NULL,
    IN_LAST_BATCH BOOLEAN NOT NULL,
    AM_ASIN CHAR(14) NULL, 
    SALE_PRICE DECIMAL(12, 2) NULL, 
    SALE_DATE DATE NULL, 
    NEW_VALUE DECIMAL(12, 2) NULL, 
    NEW_COUNT INTEGER NULL, 
    USED_VALUE DECIMAL(12, 2) NULL, 
    USED_COUNT INTEGER NULL, 
    COLLECTIBLE_VALUE DECIMAL(12, 2) NULL, 
    COLLECTIBLE_COUNT INTEGER NULL, 
    BUYER_WAITING BOOLEAN NULL,
    WEIGHT VARCHAR(32) NULL, 
    SALES_RANK INTEGER NOT NULL, 
    THUMB_IMAGE_COUNT INTEGER NOT NULL,
    FULL_IMAGE_COUNT INTEGER NOT NULL,
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    USER3 VARCHAR(255) NULL, 
    USER4 VARCHAR(255) NULL, 
    USER5 VARCHAR(255) NULL, 
    USER6 VARCHAR(255) NULL, 
    USER7 VARCHAR(255) NULL, 
    USER8 VARCHAR(255) NULL, 
    USER9 VARCHAR(255) NULL, 
    USER10 VARCHAR(255) NULL, 
    USERL1 BIGINT NULL, 
    USERL2 BIGINT NULL, 
    USERL3 BIGINT NULL, 
    USERL4 BIGINT NULL, 
    USERL5 BIGINT NULL, 
    USERL6 BIGINT NULL, 
    USERL7 BIGINT NULL, 
    USERL8 BIGINT NULL, 
    USERL9 BIGINT NULL, 
    USERL10 BIGINT NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    FILLER3 VARCHAR(255) NULL, 
    FILLER4 VARCHAR(255) NULL, 
    FILLER5 VARCHAR(255) NULL, 
    FILLER6 VARCHAR(255) NULL, 
    FILLER7 VARCHAR(255) NULL, 
    FILLER8 VARCHAR(255) NULL, 
    FILLER9 VARCHAR(255) NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the ReaderwareAW Disks table
CREATE CACHED TABLE AUDIOWARE_DISKS (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    ALBUM_ID BIGINT NOT NULL,
    DISK_NUMBER INTEGER NOT NULL,
    DISK_TITLE VARCHAR(255) NULL, 
    DISK_SIDE_BREAK INTEGER NOT NULL,
    DISK_UNIT_NUMBER INTEGER NULL,
    DISK_SLOT_NUMBER INTEGER NULL,
    DISK_RUNNING_TIME INTEGER NULL, 
    DISK_USER1 VARCHAR(255) NULL, 
    DISK_USER2 VARCHAR(255) NULL, 
    DISK_FILLER1 VARCHAR(255) NULL, 
    DISK_FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ALBUM_ID) REFERENCES AUDIOWARE(ROWKEY)
);


-- Create the ReaderwareAW Tracks table
CREATE CACHED TABLE AUDIOWARE_TRACKS (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    DISK_ID BIGINT NOT NULL,
    TRK_NUMBER INTEGER NOT NULL,
    TRK_TITLE VARCHAR(255) NULL, 
    TRK_ARTIST BIGINT NULL, 
    TRK_COMPOSER BIGINT NULL, 
    TRK_CONDUCTOR BIGINT NULL, 
    TRK_ORCHESTRA BIGINT NULL, 
    TRK_SOLOIST BIGINT NULL, 
    TRK_WORK_TITLE VARCHAR(255) NULL, 
    TRK_SONGWRITER VARCHAR(75) NULL,
    TRK_RUNNING_TIME INTEGER NULL, 
    TRK_MY_RATING BIGINT NULL, 
    TRK_FAVORITE BOOLEAN NOT NULL,
    TRK_PLAYLIST BOOLEAN NOT NULL,
    TRK_BONUS_TRACK BOOLEAN NOT NULL,
    TRK_PLAYED_COUNT INTEGER NOT NULL,
    TRK_BPM INTEGER NOT NULL,
    TRK_COMMENTS VARCHAR(255), 
    TRK_MEDIA_URL VARCHAR(255), 
    TRK_USER1 VARCHAR(255), 
    TRK_USER2 VARCHAR(255), 
    TRK_FILLER1 VARCHAR(255) NULL, 
    TRK_FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(DISK_ID) REFERENCES AUDIOWARE_DISKS(ROWKEY)
);


-- Create the Readerware Image tables
CREATE CACHED TABLE THUMB_IMAGES (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA VARBINARY(65536) NULL, 
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES AUDIOWARE(ROWKEY)
);

CREATE CACHED TABLE FULL_IMAGES (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA VARBINARY(262144) NULL, 
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES AUDIOWARE(ROWKEY)
);


-- Create the ReaderwareAW Contributor table
CREATE CACHED TABLE CONTRIBUTOR (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    NAME VARCHAR(128) NOT NULL,
    SORT_NAME VARCHAR(128) NULL,
    ROLE1 INTEGER NULL,
    ROLE2 INTEGER NULL,
    ROLE3 INTEGER NULL,
    BIO VARCHAR(32768) NULL, 
    FAVORITE BOOLEAN NOT NULL,
    BIRTH_DATE DATE NULL, 
    BIRTH_PLACE VARCHAR(128) NULL,
    DEATH_DATE DATE NULL, 
    DEATH_PLACE VARCHAR(128) NULL,
    NOTES VARCHAR(32768) NULL, 
    CONTRIB_URL VARCHAR(255) NULL, 
    IMAGE_DATA VARBINARY(32768) NULL, 
    EXTERNAL_ID VARCHAR(32) NULL, 
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY)
);


-- Create the Category table
CREATE CACHED TABLE CATEGORY_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Condition table
CREATE CACHED TABLE CONDITION_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Publisher (Label) table
CREATE CACHED TABLE PUBLISHER_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Type table
CREATE CACHED TABLE TYPE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Format table
CREATE CACHED TABLE FORMAT_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Location table
CREATE CACHED TABLE LOCATION_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the User Rating table
CREATE CACHED TABLE MY_RATING_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Series table
CREATE CACHED TABLE SERIES_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Sound table
CREATE CACHED TABLE SOUND_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Language table
CREATE CACHED TABLE LANGUAGE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Source table
CREATE CACHED TABLE SOURCE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Purchase Place table
CREATE CACHED TABLE PURCHASE_PLACE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Owner table
CREATE CACHED TABLE OWNER_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Status table
CREATE CACHED TABLE STATUS_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the User List table
CREATE CACHED TABLE USER_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LIST_NUMBER INTEGER NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Recording table
CREATE CACHED TABLE RECORDING_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Loan table
CREATE CACHED TABLE LOANS (
    LN_ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LN_ITEM_ROWKEY BIGINT NOT NULL,
    LN_BRWR_ROWKEY BIGINT NOT NULL,
    LN_ITEM_COPY_ID VARCHAR(255) NULL,
    LN_STATUS INTEGER NULL,
    LN_OUT_DATE DATE NOT NULL, 
    LN_DUE_DATE DATE NULL, 
    LN_IN_DATE DATE NULL, 
    LN_USER1 VARCHAR(255) NULL, 
    LN_USER2 VARCHAR(255) NULL, 
    LN_FILLER1 VARCHAR(255) NULL, 
    LN_FILLER2 VARCHAR(255) NULL,
    PRIMARY KEY(LN_ROWKEY)
);


-- Create the Borrower table
CREATE CACHED TABLE BORROWER (
    BRWR_ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    BRWR_FNAME VARCHAR(100) NULL,
    BRWR_LNAME VARCHAR(100) NULL,
    BRWR_ID VARCHAR(32) NULL,
    BRWR_STATUS INTEGER NULL,
    BRWR_EMAIL VARCHAR(100) NULL, 
    BRWR_PHONE1 VARCHAR(32) NULL,
    BRWR_PHONE2 VARCHAR(32) NULL,
    BRWR_FAX VARCHAR(32) NULL,
    BRWR_ORG VARCHAR(100) NULL,
    BRWR_ADDR1 VARCHAR(100) NULL,
    BRWR_ADDR2 VARCHAR(100) NULL,
    BRWR_CITY VARCHAR(100) NULL,
    BRWR_STATE VARCHAR(32) NULL,
    BRWR_ZIP VARCHAR(32) NULL,
    BRWR_USER1 VARCHAR(255) NULL, 
    BRWR_USER2 VARCHAR(255) NULL, 
    BRWR_FILLER1 VARCHAR(255) NULL, 
    BRWR_FILLER2 VARCHAR(255) NULL, 
    UNIQUE (BRWR_ID),
    PRIMARY KEY(BRWR_ROWKEY)
);


-- Create the Borrower Patron Type table
CREATE CACHED TABLE BRWR_PATRON_TYPE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY(START WITH 1, INCREMENT BY 1) NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Preferences table
CREATE CACHED TABLE PREFERENCES (
    PREFS_KEY VARCHAR(128) NOT NULL,
    PREFS_VALUE VARCHAR(4096) NOT NULL, 
    PRIMARY KEY(PREFS_KEY)
);
