
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.


-- Internal table
-- Must be present
CREATE TABLE DBCATALOG40 (
    ROWKEY BIGSERIAL,
    EV DATE NOT NULL,
    EV_DESC VARCHAR(255) NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create main ReaderwareAW table
CREATE TABLE AUDIOWARE (
    ROWKEY BIGSERIAL,
    TITLE VARCHAR(255) NOT NULL, 
    ARTIST BIGINT, 
    ARTIST2 BIGINT,
    ARTIST3 BIGINT,
    ARTIST4 BIGINT,
    ARTIST5 BIGINT,
    ARTIST6 BIGINT,
    COMPOSER BIGINT, 
    CONDUCTOR BIGINT, 
    ORCHESTRA BIGINT, 
    SOLOIST BIGINT, 
    WORK_TITLE VARCHAR(255), 
    PUBLISHER BIGINT, 
    RELEASE_DATE DATE, 
    COPYRIGHT_DATE DATE, 
    RUNNING_TIME INTEGER, 
    CONTENT_LANGUAGE BIGINT, 
    COPIES INTEGER NOT NULL, 
    BARCODE VARCHAR(128), 
    UPC VARCHAR(25), 
    LCCN VARCHAR(16), 
    DEWEY VARCHAR(32), 
    CALL_NUMBER VARCHAR(32), 
    USER_NUMBER VARCHAR(32), 
    TYPE BIGINT, 
    FORMAT BIGINT,  
    SERIES BIGINT, 
    SOUND BIGINT, 
    MY_RATING BIGINT, 
    ITEM_CONDITION BIGINT, 
    COVER_CONDITION BIGINT, 
    CATEGORY1 BIGINT, 
    CATEGORY2 BIGINT, 
    CATEGORY3 BIGINT, 
    LOCATION BIGINT, 
    KEYWORDS VARCHAR(255), 
    PLAYED_COUNT INTEGER NOT NULL, 
    DATE_LAST_PLAYED DATE, 
    PLAYLIST BOOLEAN NOT NULL,
    PRODUCT_INFO VARCHAR(65536), 
    MY_COMMENTS VARCHAR(65536), 
    DATE_ENTERED DATE NOT NULL, 
    DATE_LAST_UPDATED DATE NOT NULL, 
    SOURCE BIGINT, 
    CATALOG_NUMBER VARCHAR(50), 
    RECORDING_TYPE BIGINT, 
    RECORDING_DATE DATE, 
    RECORDING_PLACE VARCHAR(128), 
    PURCHASE_PRICE DECIMAL(12, 2) NOT NULL, 
    PURCHASE_DATE DATE, 
    PURCHASE_PLACE BIGINT, 
    LIST_PRICE DECIMAL(12, 2) NOT NULL, 
    ITEM_VALUE DECIMAL(12, 2) NOT NULL, 
    VALUATION_DATE DATE, 
    CURRENCY_SYMBOL VARCHAR(5), 
    FAVORITE BOOLEAN NOT NULL,
    OUT_OF_PRINT BOOLEAN NOT NULL,
    MEDIA_URL VARCHAR(255), 
    OWNER BIGINT,
    STATUS BIGINT,
    EXTERNAL_ID VARCHAR(32), 
    INVENTORY INTEGER NOT NULL,
    IN_LAST_BATCH BOOLEAN NOT NULL,
    AM_ASIN CHAR(14), 
    SALE_PRICE DECIMAL(12, 2), 
    SALE_DATE DATE, 
    NEW_VALUE DECIMAL(12, 2), 
    NEW_COUNT INTEGER, 
    USED_VALUE DECIMAL(12, 2), 
    USED_COUNT INTEGER, 
    COLLECTIBLE_VALUE DECIMAL(12, 2), 
    COLLECTIBLE_COUNT INTEGER, 
    BUYER_WAITING BOOLEAN,
    WEIGHT VARCHAR(32), 
    SALES_RANK INTEGER NOT NULL, 
    THUMB_IMAGE_COUNT INTEGER NOT NULL,
    FULL_IMAGE_COUNT INTEGER NOT NULL,
    USER1 VARCHAR(255), 
    USER2 VARCHAR(255), 
    USER3 VARCHAR(255), 
    USER4 VARCHAR(255), 
    USER5 VARCHAR(255), 
    USER6 VARCHAR(255), 
    USER7 VARCHAR(255), 
    USER8 VARCHAR(255), 
    USER9 VARCHAR(255), 
    USER10 VARCHAR(255), 
    USERL1 BIGINT, 
    USERL2 BIGINT, 
    USERL3 BIGINT, 
    USERL4 BIGINT, 
    USERL5 BIGINT, 
    USERL6 BIGINT, 
    USERL7 BIGINT, 
    USERL8 BIGINT, 
    USERL9 BIGINT, 
    USERL10 BIGINT, 
    FILLER1 VARCHAR(255), 
    FILLER2 VARCHAR(255), 
    FILLER3 VARCHAR(255), 
    FILLER4 VARCHAR(255), 
    FILLER5 VARCHAR(255), 
    FILLER6 VARCHAR(255), 
    FILLER7 VARCHAR(255), 
    FILLER8 VARCHAR(255), 
    FILLER9 VARCHAR(255),
    PRIMARY KEY(ROWKEY)
);


-- Create the ReaderwareAW Disks table
CREATE TABLE AUDIOWARE_DISKS (
    ROWKEY BIGSERIAL,
    ALBUM_ID BIGINT NOT NULL,
    DISK_NUMBER INTEGER NOT NULL,
    DISK_TITLE VARCHAR(255), 
    DISK_SIDE_BREAK INTEGER NOT NULL,
    DISK_UNIT_NUMBER INTEGER,
    DISK_SLOT_NUMBER INTEGER,
    DISK_RUNNING_TIME INTEGER, 
    DISK_USER1 VARCHAR(255), 
    DISK_USER2 VARCHAR(255), 
    DISK_FILLER1 VARCHAR(255), 
    DISK_FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ALBUM_ID) REFERENCES AUDIOWARE(ROWKEY)
);


-- Create the ReaderwareAW Tracks table
CREATE TABLE AUDIOWARE_TRACKS (
    ROWKEY BIGSERIAL,
    DISK_ID BIGINT NOT NULL,
    TRK_NUMBER INTEGER NOT NULL,
    TRK_TITLE VARCHAR(255), 
    TRK_ARTIST BIGINT, 
    TRK_COMPOSER BIGINT, 
    TRK_CONDUCTOR BIGINT, 
    TRK_ORCHESTRA BIGINT, 
    TRK_SOLOIST BIGINT, 
    TRK_WORK_TITLE VARCHAR(255), 
    TRK_SONGWRITER VARCHAR(75),
    TRK_RUNNING_TIME INTEGER, 
    TRK_MY_RATING BIGINT, 
    TRK_FAVORITE BOOLEAN NOT NULL,
    TRK_PLAYLIST BOOLEAN NOT NULL,
    TRK_BONUS_TRACK BOOLEAN NOT NULL,
    TRK_PLAYED_COUNT INTEGER NOT NULL,
    TRK_BPM INTEGER NOT NULL,
    TRK_COMMENTS VARCHAR(255), 
    TRK_MEDIA_URL VARCHAR(255), 
    TRK_USER1 VARCHAR(255), 
    TRK_USER2 VARCHAR(255), 
    TRK_FILLER1 VARCHAR(255), 
    TRK_FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(DISK_ID) REFERENCES AUDIOWARE_DISKS(ROWKEY)
);


-- Create the Readerware Image tables
CREATE TABLE THUMB_IMAGES (
    ROWKEY BIGSERIAL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA BYTEA,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES AUDIOWARE(ROWKEY)
);

CREATE TABLE FULL_IMAGES (
    ROWKEY BIGSERIAL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA BYTEA,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES AUDIOWARE(ROWKEY)
);


-- Create the ReaderwareAW Contributor table
CREATE TABLE CONTRIBUTOR (
    ROWKEY BIGSERIAL,
    NAME VARCHAR(128) NOT NULL,
    SORT_NAME VARCHAR(128),
    ROLE1 INTEGER,
    ROLE2 INTEGER,
    ROLE3 INTEGER,
    BIO VARCHAR(32768), 
    FAVORITE BOOLEAN NOT NULL,
    BIRTH_DATE DATE, 
    BIRTH_PLACE VARCHAR(128),
    DEATH_DATE DATE, 
    DEATH_PLACE VARCHAR(128),
    NOTES VARCHAR(32768), 
    CONTRIB_URL VARCHAR(255), 
    IMAGE_DATA BYTEA,
    EXTERNAL_ID VARCHAR(32), 
    USER1 VARCHAR(255), 
    USER2 VARCHAR(255), 
    FILLER1 VARCHAR(255), 
    FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY)
);


-- Create the Language table
CREATE TABLE LANGUAGE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Category table
CREATE TABLE CATEGORY_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Condition table
CREATE TABLE CONDITION_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Publisher (Label) table
CREATE TABLE PUBLISHER_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Type table
CREATE TABLE TYPE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Format table
CREATE TABLE FORMAT_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Location table
CREATE TABLE LOCATION_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the User Rating table
CREATE TABLE MY_RATING_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Series table
CREATE TABLE SERIES_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Sound table
CREATE TABLE SOUND_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Source table
CREATE TABLE SOURCE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Purchase Place table
CREATE TABLE PURCHASE_PLACE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Owner table
CREATE TABLE OWNER_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Status table
CREATE TABLE STATUS_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the User List table
CREATE TABLE USER_LIST (
    ROWKEY BIGSERIAL,
    LIST_NUMBER INTEGER NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Recording table
CREATE TABLE RECORDING_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Loan table
CREATE TABLE LOANS (
    LN_ROWKEY BIGSERIAL,
    LN_ITEM_ROWKEY BIGINT NOT NULL,
    LN_BRWR_ROWKEY BIGINT NOT NULL,
    LN_ITEM_COPY_ID VARCHAR(255),
    LN_STATUS INTEGER,
    LN_OUT_DATE DATE NOT NULL, 
    LN_DUE_DATE DATE, 
    LN_IN_DATE DATE, 
    LN_USER1 VARCHAR(255), 
    LN_USER2 VARCHAR(255), 
    LN_FILLER1 VARCHAR(255), 
    LN_FILLER2 VARCHAR(255),
    PRIMARY KEY(LN_ROWKEY)
);


-- Create the Borrower table
CREATE TABLE BORROWER (
    BRWR_ROWKEY BIGSERIAL,
    BRWR_FNAME VARCHAR(100),
    BRWR_LNAME VARCHAR(100),
    BRWR_ID VARCHAR(32),
    BRWR_STATUS INTEGER,
    BRWR_EMAIL VARCHAR(100), 
    BRWR_PHONE1 VARCHAR(32),
    BRWR_PHONE2 VARCHAR(32),
    BRWR_FAX VARCHAR(32),
    BRWR_ORG VARCHAR(100),
    BRWR_ADDR1 VARCHAR(100),
    BRWR_ADDR2 VARCHAR(100),
    BRWR_CITY VARCHAR(100),
    BRWR_STATE VARCHAR(32),
    BRWR_ZIP VARCHAR(32),
    BRWR_USER1 VARCHAR(255), 
    BRWR_USER2 VARCHAR(255), 
    BRWR_FILLER1 VARCHAR(255), 
    BRWR_FILLER2 VARCHAR(255), 
    UNIQUE (BRWR_ID),
    PRIMARY KEY(BRWR_ROWKEY)
);


-- Create the Borrower Patron Type table
CREATE TABLE BRWR_PATRON_TYPE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Preferences table
CREATE TABLE PREFERENCES (
    PREFS_KEY VARCHAR(128) NOT NULL,
    PREFS_VALUE VARCHAR(4096) NOT NULL, 
    PRIMARY KEY(PREFS_KEY)
);
