
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.

-- Internal table
-- Must be present
CREATE TABLE DBCATALOG40 (
    ROWKEY AUTOINCREMENT NOT NULL PRIMARY KEY,
    EV DATE NOT NULL,
    EV_DESC VARCHAR(255) NULL
);


-- Create main Readerware table
CREATE TABLE READERWARE (
    ROWKEY AUTOINCREMENT NOT NULL PRIMARY KEY,
    TITLE VARCHAR(255) NOT NULL, 
    ALT_TITLE VARCHAR(255) NULL, 
    SUBTITLE VARCHAR(255) NULL, 
    AUTHOR INTEGER NULL, 
    AUTHOR2 INTEGER NULL,
    AUTHOR3 INTEGER NULL,
    AUTHOR4 INTEGER NULL,
    AUTHOR5 INTEGER NULL,
    AUTHOR6 INTEGER NULL,
    ILLUSTRATOR INTEGER NULL,
    TRANSLATOR INTEGER NULL,
    EDITOR INTEGER NULL,
    PUBLISHER INTEGER NULL, 
    PUB_PLACE INTEGER NULL, 
    RELEASE_DATE DATE NULL, 
    COPYRIGHT_DATE DATE NULL, 
    PAGES SMALLINT NULL, 
    EDITION INTEGER NULL, 
    CONTENT_LANGUAGE INTEGER NULL, 
    SIGNED INTEGER NULL, 
    DIMENSIONS VARCHAR(32) NULL, 
    READING_LEVEL INTEGER NULL, 
    LEXILE_LEVEL CHAR(14) NULL, 
    COPIES SMALLINT NOT NULL, 
    BARCODE VARCHAR(128) NULL, 
    ISBN CHAR(14) NULL, 
    ISSN CHAR(16) NULL, 
    LCCN VARCHAR(16) NULL, 
    DEWEY VARCHAR(32) NULL, 
    CALL_NUMBER VARCHAR(32) NULL, 
    USER_NUMBER VARCHAR(32) NULL, 
    TYPE INTEGER NULL, 
    FORMAT INTEGER NULL, 
    SERIES INTEGER NULL, 
    SERIES_NUMBER DOUBLE NOT NULL, 
    MY_RATING INTEGER NULL, 
    ITEM_CONDITION INTEGER NULL, 
    COVER_CONDITION INTEGER NULL, 
    CATEGORY1 INTEGER NULL, 
    CATEGORY2 INTEGER NULL, 
    CATEGORY3 INTEGER NULL, 
    LOCATION INTEGER NULL, 
    KEYWORDS VARCHAR(255) NULL, 
    READ_COUNT SMALLINT NOT NULL, 
    DATE_LAST_READ DATE NULL, 
    PRODUCT_INFO MEMO NULL, 
    MY_COMMENTS MEMO NULL, 
    DATE_ENTERED DATE NOT NULL, 
    DATE_LAST_UPDATED DATE NOT NULL, 
    SOURCE INTEGER NULL, 
    PURCHASE_PRICE CURRENCY NOT NULL, 
    PURCHASE_DATE DATE NULL, 
    PURCHASE_PLACE INTEGER NULL, 
    LIST_PRICE CURRENCY NOT NULL, 
    ITEM_VALUE CURRENCY NOT NULL, 
    VALUATION_DATE DATE NULL, 
    CURRENCY_SYMBOL VARCHAR(5) NULL, 
    FAVORITE BIT NOT NULL,
    OUT_OF_PRINT BIT NOT NULL,
    MEDIA_URL VARCHAR(255) NULL, 
    OWNER INTEGER NULL, 
    STATUS INTEGER NULL, 
    EXTERNAL_ID VARCHAR(32) NULL, 
    INVENTORY SMALLINT NOT NULL,
    IN_LAST_BATCH BIT NOT NULL,
    AM_ASIN CHAR(14) NULL, 
    SALE_PRICE CURRENCY NULL, 
    SALE_DATE DATE NULL, 
    NEW_VALUE CURRENCY NULL, 
    NEW_COUNT SMALLINT NULL, 
    USED_VALUE CURRENCY NULL, 
    USED_COUNT SMALLINT NULL, 
    COLLECTIBLE_VALUE CURRENCY NULL, 
    COLLECTIBLE_COUNT SMALLINT NULL, 
    BUYER_WAITING BIT NULL,
    WEIGHT VARCHAR(32) NULL, 
    SALES_RANK INTEGER NOT NULL, 
    THUMB_IMAGE_COUNT INTEGER NOT NULL,
    FULL_IMAGE_COUNT INTEGER NOT NULL,
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    USER3 VARCHAR(255) NULL, 
    USER4 VARCHAR(255) NULL, 
    USER5 VARCHAR(255) NULL, 
    USER6 VARCHAR(255) NULL, 
    USER7 VARCHAR(255) NULL, 
    USER8 VARCHAR(255) NULL, 
    USER9 VARCHAR(255) NULL, 
    USER10 VARCHAR(255) NULL, 
    USERL1 INTEGER NULL, 
    USERL2 INTEGER NULL, 
    USERL3 INTEGER NULL, 
    USERL4 INTEGER NULL, 
    USERL5 INTEGER NULL, 
    USERL6 INTEGER NULL, 
    USERL7 INTEGER NULL, 
    USERL8 INTEGER NULL, 
    USERL9 INTEGER NULL, 
    USERL10 INTEGER NULL, 
    FILLER1 VARCHAR(255) NULL,  
    FILLER2 VARCHAR(255) NULL, 
    FILLER3 VARCHAR(255) NULL, 
    FILLER4 VARCHAR(255) NULL, 
    FILLER5 VARCHAR(255) NULL, 
    FILLER6 VARCHAR(255) NULL, 
    FILLER7 VARCHAR(255) NULL, 
    FILLER8 VARCHAR(255) NULL, 
    FILLER9 VARCHAR(255) NULL, 
    FILLER10 VARCHAR(255) NULL
);


-- Create the Readerware Volumes table
CREATE TABLE READERWARE_VOLUMES (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    BOOK_ID INTEGER NOT NULL REFERENCES READERWARE (ROWKEY),
    VOL_NUMBER SMALLINT NOT NULL,
    VOL_TITLE VARCHAR(255) NULL, 
    VOL_USER1 VARCHAR(255), 
    VOL_USER2 VARCHAR(255), 
    VOL_FILLER1 VARCHAR(255) NULL, 
    VOL_FILLER2 VARCHAR(255) NULL
);


-- Create the Readerware Chapters table
CREATE TABLE READERWARE_CHAPTERS (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    VOL_ID INTEGER NOT NULL REFERENCES READERWARE_VOLUMES (ROWKEY),
    CHP_NUMBER SMALLINT NOT NULL,
    CHP_TITLE VARCHAR(255) NULL, 
    CHP_AUTHOR INTEGER NULL, 
    CHP_ILLUSTRATOR INTEGER NULL, 
    CHP_TRANSLATOR INTEGER NULL, 
    CHP_EDITOR INTEGER NULL, 
    CHP_MY_RATING INTEGER NULL, 
    CHP_FAVORITE BIT NOT NULL,
    CHP_READ_COUNT SMALLINT NOT NULL,
    CHP_COMMENTS VARCHAR(255) NULL, 
    CHP_MEDIA_URL VARCHAR(255) NULL, 
    CHP_USER1 VARCHAR(255) NULL, 
    CHP_USER2 VARCHAR(255) NULL, 
    CHP_FILLER1 VARCHAR(255) NULL, 
    CHP_FILLER2 VARCHAR(255) NULL
);


-- Create the Readerware Image tables
CREATE TABLE THUMB_IMAGES (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    ROW_ID INTEGER NOT NULL REFERENCES READERWARE(ROWKEY),
    IMAGE_INDEX SMALLINT NOT NULL,
    IMAGE_DATA IMAGE NULL,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
);

CREATE TABLE FULL_IMAGES (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    ROW_ID INTEGER NOT NULL REFERENCES READERWARE(ROWKEY),
    IMAGE_INDEX SMALLINT NOT NULL,
    IMAGE_DATA IMAGE NULL,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
);


-- Create the Readerware Contributor table
CREATE TABLE CONTRIBUTOR (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    NAME VARCHAR(128) NOT NULL,
    SORT_NAME VARCHAR(128) NULL,
    ROLE1 SMALLINT NULL,
    ROLE2 SMALLINT NULL,
    ROLE3 SMALLINT NULL,
    BIO MEMO NULL, 
    FAVORITE BIT NOT NULL,
    BIRTH_DATE DATE NULL, 
    BIRTH_PLACE VARCHAR(128) NULL,
    DEATH_DATE DATE NULL, 
    DEATH_PLACE VARCHAR(128) NULL,
    NOTES MEMO NULL, 
    CONTRIB_URL VARCHAR(255) NULL, 
    IMAGE_DATA IMAGE NULL, 
    EXTERNAL_ID VARCHAR(32) NULL, 
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL
);


-- Create the Publisher table
CREATE TABLE PUBLISHER_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Publication Place table
CREATE TABLE PUBLICATION_PLACE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Edition table
CREATE TABLE EDITION_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Language table
CREATE TABLE LANGUAGE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Signed table
CREATE TABLE SIGNED_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Reading Level table
CREATE TABLE READING_LEVEL_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Type table
CREATE TABLE TYPE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Format table
CREATE TABLE FORMAT_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Series table
CREATE TABLE SERIES_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the User Rating table
CREATE TABLE MY_RATING_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Condition table
CREATE TABLE CONDITION_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Category table
CREATE TABLE CATEGORY_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Location table
CREATE TABLE LOCATION_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Source table
CREATE TABLE SOURCE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Purchase Place table
CREATE TABLE PURCHASE_PLACE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Owner table
CREATE TABLE OWNER_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Status table
CREATE TABLE STATUS_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the User List table
CREATE TABLE USER_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LIST_NUMBER SMALLINT NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Loan table
CREATE TABLE LOANS (
    LN_ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LN_ITEM_ROWKEY INTEGER NOT NULL,
    LN_BRWR_ROWKEY INTEGER NOT NULL,
    LN_ITEM_COPY_ID VARCHAR(255) NULL,
    LN_STATUS SMALLINT NULL,
    LN_OUT_DATE DATE NOT NULL, 
    LN_DUE_DATE DATE NULL, 
    LN_IN_DATE DATE NULL, 
    LN_USER1 VARCHAR(255) NULL, 
    LN_USER2 VARCHAR(255) NULL, 
    LN_FILLER1 VARCHAR(255) NULL, 
    LN_FILLER2 VARCHAR(255) NULL
);


-- Create the Borrower table
CREATE TABLE BORROWER (
    BRWR_ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    BRWR_FNAME VARCHAR(100) NULL,
    BRWR_LNAME VARCHAR(100) NULL,
    BRWR_ID VARCHAR(32) NULL,
    BRWR_STATUS SMALLINT NULL,
    BRWR_EMAIL VARCHAR(100) NULL, 
    BRWR_PHONE1 VARCHAR(32) NULL,
    BRWR_PHONE2 VARCHAR(32) NULL,
    BRWR_FAX VARCHAR(32) NULL,
    BRWR_ORG VARCHAR(100) NULL,
    BRWR_ADDR1 VARCHAR(100) NULL,
    BRWR_ADDR2 VARCHAR(100) NULL,
    BRWR_CITY VARCHAR(100) NULL,
    BRWR_STATE VARCHAR(32) NULL,
    BRWR_ZIP VARCHAR(32) NULL,
    BRWR_PATRON_TYPE INTEGER NULL, 
    BRWR_READING_LEVEL INTEGER NULL, 
    BRWR_LEXILE_LEVEL CHAR(14) NULL, 
    BRWR_USER1 VARCHAR(255) NULL, 
    BRWR_USER2 VARCHAR(255) NULL, 
    BRWR_FILLER1 VARCHAR(255) NULL, 
    BRWR_FILLER2 VARCHAR(255) NULL, 
    UNIQUE (BRWR_ID)
);


-- Create the Borrower Patron Type table
CREATE TABLE BRWR_PATRON_TYPE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Preferences table
CREATE TABLE PREFERENCES (
    PREFS_KEY VARCHAR(128) PRIMARY KEY NOT NULL,
    PREFS_VALUE VARCHAR(4096) NOT NULL
);
