
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.


-- Internal table
-- Must be present
CREATE TABLE DBCATALOG (
    EV DATE NOT NULL
);


-- Create main Readerware table
CREATE TABLE READERWARE (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    TITLE VARCHAR(255) NOT NULL, 
    ALT_TITLE VARCHAR(255), 
    SUBTITLE VARCHAR(255), 
    AUTHOR BIGINT, 
    AUTHOR2 BIGINT,
    AUTHOR3 BIGINT,
    AUTHOR4 BIGINT,
    AUTHOR5 BIGINT,
    AUTHOR6 BIGINT,
    ILLUSTRATOR BIGINT,
    TRANSLATOR BIGINT,
    EDITOR BIGINT,
    PUBLISHER BIGINT, 
    PUB_PLACE BIGINT, 
    RELEASE_DATE DATE, 
    COPYRIGHT_DATE DATE, 
    PAGES INTEGER, 
    EDITION BIGINT, 
    CONTENT_LANGUAGE BIGINT, 
    SIGNED BIGINT, 
    DIMENSIONS VARCHAR(32), 
    READING_LEVEL BIGINT, 
    LEXILE_LEVEL CHAR(14), 
    COPIES INTEGER NOT NULL, 
    BARCODE VARCHAR(128), 
    ISBN CHAR(14), 
    ISSN CHAR(16), 
    LCCN VARCHAR(16), 
    DEWEY VARCHAR(32), 
    CALL_NUMBER VARCHAR(32), 
    USER_NUMBER VARCHAR(32), 
    TYPE BIGINT, 
    FORMAT BIGINT, 
    SERIES BIGINT, 
    SERIES_NUMBER INTEGER, 
    MY_RATING BIGINT, 
    ITEM_CONDITION BIGINT, 
    COVER_CONDITION BIGINT, 
    CATEGORY1 BIGINT, 
    CATEGORY2 BIGINT, 
    CATEGORY3 BIGINT, 
    LOCATION BIGINT, 
    KEYWORDS VARCHAR(255), 
    READ_COUNT INTEGER NOT NULL, 
    DATE_LAST_READ DATE, 
    PRODUCT_INFO VARCHAR(32672), 
    MY_COMMENTS VARCHAR(32672), 
    DATE_ENTERED DATE NOT NULL, 
    DATE_LAST_UPDATED DATE NOT NULL, 
    SOURCE BIGINT, 
    PURCHASE_PRICE DECIMAL(12, 2) NOT NULL, 
    PURCHASE_DATE DATE, 
    PURCHASE_PLACE BIGINT, 
    LIST_PRICE DECIMAL(12, 2) NOT NULL, 
    ITEM_VALUE DECIMAL(12, 2) NOT NULL, 
    VALUATION_DATE DATE, 
    CURRENCY_SYMBOL VARCHAR(5), 
    FAVORITE SMALLINT NOT NULL,
    OUT_OF_PRINT SMALLINT NOT NULL,
    MEDIA_URL VARCHAR(255), 
    OWNER BIGINT, 
    STATUS BIGINT, 
    EXTERNAL_ID VARCHAR(32), 
    INVENTORY INTEGER NOT NULL,
    IMAGE1_DATA BLOB(65536), 
    IMAGE2_DATA BLOB(65536), 
    IMAGE1_LARGE_DATA BLOB(262144), 
    IMAGE2_LARGE_DATA BLOB(262144), 
    IN_LAST_BATCH SMALLINT NOT NULL,
    AM_ASIN CHAR(14), 
    SALE_PRICE DECIMAL(12, 2), 
    SALE_DATE DATE, 
    NEW_VALUE DECIMAL(12, 2), 
    NEW_COUNT INTEGER, 
    USED_VALUE DECIMAL(12, 2), 
    USED_COUNT INTEGER, 
    COLLECTIBLE_VALUE DECIMAL(12, 2), 
    COLLECTIBLE_COUNT INTEGER, 
    BUYER_WAITING SMALLINT,
    WEIGHT VARCHAR(32), 
    USER1 VARCHAR(255), 
    USER2 VARCHAR(255), 
    USER3 VARCHAR(255), 
    USER4 VARCHAR(255), 
    USER5 VARCHAR(255), 
    USER6 VARCHAR(255), 
    USER7 VARCHAR(255), 
    USER8 VARCHAR(255), 
    USER9 VARCHAR(255), 
    USER10 VARCHAR(255), 
    FILLER1 VARCHAR(255),  
    FILLER2 VARCHAR(255), 
    FILLER3 VARCHAR(255), 
    FILLER4 VARCHAR(255), 
    FILLER5 VARCHAR(255), 
    FILLER6 VARCHAR(255), 
    FILLER7 VARCHAR(255), 
    FILLER8 VARCHAR(255), 
    FILLER9 VARCHAR(255), 
    FILLER10 VARCHAR(255),  
    PRIMARY KEY(ROWKEY)
);


-- Create the Readerware Volumes table
CREATE TABLE READERWARE_VOLUMES (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    BOOK_ID BIGINT NOT NULL,
    VOL_NUMBER INTEGER NOT NULL,
    VOL_TITLE VARCHAR(255), 
    VOL_USER1 VARCHAR(255), 
    VOL_USER2 VARCHAR(255), 
    VOL_FILLER1 VARCHAR(255), 
    VOL_FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(BOOK_ID) REFERENCES READERWARE(ROWKEY)
);


-- Create the Readerware Chapters table
CREATE TABLE READERWARE_CHAPTERS (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    VOL_ID BIGINT NOT NULL,
    CHP_NUMBER INTEGER NOT NULL,
    CHP_TITLE VARCHAR(255), 
    CHP_AUTHOR BIGINT, 
    CHP_ILLUSTRATOR BIGINT, 
    CHP_TRANSLATOR BIGINT, 
    CHP_EDITOR BIGINT, 
    CHP_MY_RATING BIGINT, 
    CHP_FAVORITE SMALLINT NOT NULL,
    CHP_READ_COUNT INTEGER NOT NULL,
    CHP_COMMENTS VARCHAR(255), 
    CHP_MEDIA_URL VARCHAR(255), 
    CHP_USER1 VARCHAR(255), 
    CHP_USER2 VARCHAR(255), 
    CHP_FILLER1 VARCHAR(255), 
    CHP_FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(VOL_ID) REFERENCES READERWARE_VOLUMES(ROWKEY)
);


-- Create the Readerware Contributor table
CREATE TABLE CONTRIBUTOR (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    NAME VARCHAR(128) NOT NULL,
    SORT_NAME VARCHAR(128),
    ROLE1 INTEGER,
    ROLE2 INTEGER,
    ROLE3 INTEGER,
    BIO VARCHAR(32672), 
    FAVORITE SMALLINT NOT NULL,
    BIRTH_DATE DATE, 
    BIRTH_PLACE VARCHAR(128),
    DEATH_DATE DATE, 
    DEATH_PLACE VARCHAR(128),
    NOTES VARCHAR(32672), 
    CONTRIB_URL VARCHAR(255), 
    IMAGE_DATA BLOB(32768), 
    EXTERNAL_ID VARCHAR(32), 
    USER1 VARCHAR(255), 
    USER2 VARCHAR(255), 
    FILLER1 VARCHAR(255), 
    FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY)
);


-- Create the Publisher table
CREATE TABLE PUBLISHER_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Publication Place table
CREATE TABLE PUBLICATION_PLACE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Edition table
CREATE TABLE EDITION_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Language table
CREATE TABLE LANGUAGE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Signed table
CREATE TABLE SIGNED_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Reading Level table
CREATE TABLE READING_LEVEL_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Type table
CREATE TABLE TYPE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Format table
CREATE TABLE FORMAT_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Series table
CREATE TABLE SERIES_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the User Rating table
CREATE TABLE MY_RATING_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Condition table
CREATE TABLE CONDITION_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Category table
CREATE TABLE CATEGORY_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Location table
CREATE TABLE LOCATION_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Source table
CREATE TABLE SOURCE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Purchase Place table
CREATE TABLE PURCHASE_PLACE_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Owner table
CREATE TABLE OWNER_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Status table
CREATE TABLE STATUS_LIST (
    ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Loan table
CREATE TABLE LOANS (
    LN_ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    LN_ITEM_ROWKEY BIGINT NOT NULL,
    LN_BRWR_ROWKEY BIGINT NOT NULL,
    LN_ITEM_COPY_ID VARCHAR(255),
    LN_STATUS INTEGER,
    LN_OUT_DATE DATE NOT NULL, 
    LN_DUE_DATE DATE, 
    LN_IN_DATE DATE, 
    LN_USER1 VARCHAR(255), 
    LN_USER2 VARCHAR(255), 
    LN_FILLER1 VARCHAR(255), 
    LN_FILLER2 VARCHAR(255),
    PRIMARY KEY(LN_ROWKEY)
);


-- Create the Readerware table
CREATE TABLE BORROWER (
    BRWR_ROWKEY BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL,
    BRWR_FNAME VARCHAR(100) NOT NULL,
    BRWR_LNAME VARCHAR(100),
    BRWR_ID VARCHAR(32),
    BRWR_STATUS INTEGER,
    BRWR_EMAIL VARCHAR(100), 
    BRWR_PHONE1 VARCHAR(32),
    BRWR_PHONE2 VARCHAR(32),
    BRWR_FAX VARCHAR(32),
    BRWR_ORG VARCHAR(100),
    BRWR_ADDR1 VARCHAR(100),
    BRWR_ADDR2 VARCHAR(100),
    BRWR_CITY VARCHAR(100),
    BRWR_STATE VARCHAR(32),
    BRWR_ZIP VARCHAR(32),
    BRWR_USER1 VARCHAR(255), 
    BRWR_USER2 VARCHAR(255), 
    BRWR_FILLER1 VARCHAR(255), 
    BRWR_FILLER2 VARCHAR(255), 
    UNIQUE (BRWR_ID),
    PRIMARY KEY(BRWR_ROWKEY)
);
