
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.


-- Internal table
-- Must be present
CREATE TABLE DBCATALOG40 (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    EV DATE NOT NULL,
    EV_DESC VARCHAR(255) NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create main Readerware table
CREATE TABLE READERWARE (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    TITLE VARCHAR(255) NOT NULL, 
    ALT_TITLE VARCHAR(255) NULL, 
    SUBTITLE VARCHAR(255) NULL, 
    AUTHOR BIGINT NULL, 
    AUTHOR2 BIGINT NULL,
    AUTHOR3 BIGINT NULL,
    AUTHOR4 BIGINT NULL,
    AUTHOR5 BIGINT NULL,
    AUTHOR6 BIGINT NULL,
    ILLUSTRATOR BIGINT NULL,
    TRANSLATOR BIGINT NULL,
    EDITOR BIGINT NULL,
    PUBLISHER BIGINT NULL, 
    PUB_PLACE BIGINT NULL, 
    RELEASE_DATE DATE NULL, 
    COPYRIGHT_DATE DATE NULL, 
    PAGES INTEGER NULL, 
    EDITION BIGINT NULL, 
    CONTENT_LANGUAGE BIGINT NULL, 
    SIGNED BIGINT NULL, 
    DIMENSIONS VARCHAR(32) NULL, 
    READING_LEVEL BIGINT NULL, 
    LEXILE_LEVEL CHAR(14) NULL, 
    COPIES INTEGER NOT NULL, 
    BARCODE VARCHAR(128) NULL, 
    ISBN CHAR(14) NULL, 
    ISSN CHAR(16) NULL, 
    LCCN VARCHAR(16) NULL, 
    DEWEY VARCHAR(32) NULL, 
    CALL_NUMBER VARCHAR(32) NULL, 
    USER_NUMBER VARCHAR(32) NULL, 
    TYPE BIGINT NULL, 
    FORMAT BIGINT NULL, 
    SERIES BIGINT NULL, 
    SERIES_NUMBER DOUBLE NOT NULL, 
    MY_RATING BIGINT NULL, 
    ITEM_CONDITION BIGINT NULL, 
    COVER_CONDITION BIGINT NULL, 
    CATEGORY1 BIGINT NULL, 
    CATEGORY2 BIGINT NULL, 
    CATEGORY3 BIGINT NULL, 
    LOCATION BIGINT NULL, 
    KEYWORDS VARCHAR(255) NULL, 
    READ_COUNT INTEGER NOT NULL, 
    DATE_LAST_READ DATE NULL, 
    PRODUCT_INFO TEXT, 
    MY_COMMENTS TEXT, 
    DATE_ENTERED DATE NOT NULL, 
    DATE_LAST_UPDATED DATE NOT NULL, 
    SOURCE BIGINT NULL, 
    PURCHASE_PRICE DECIMAL(12, 2) NOT NULL, 
    PURCHASE_DATE DATE NULL, 
    PURCHASE_PLACE BIGINT NULL, 
    LIST_PRICE DECIMAL(12, 2) NOT NULL, 
    ITEM_VALUE DECIMAL(12, 2) NOT NULL, 
    VALUATION_DATE DATE NULL, 
    CURRENCY_SYMBOL VARCHAR(5) NULL, 
    FAVORITE BOOLEAN NOT NULL,
    OUT_OF_PRINT BOOLEAN NOT NULL,
    MEDIA_URL VARCHAR(255) NULL, 
    OWNER BIGINT NULL, 
    STATUS BIGINT NULL, 
    EXTERNAL_ID VARCHAR(32) NULL, 
    INVENTORY INTEGER NOT NULL,
    IN_LAST_BATCH BOOLEAN NOT NULL,
    AM_ASIN CHAR(14) NULL, 
    SALE_PRICE DECIMAL(12, 2) NULL, 
    SALE_DATE DATE NULL, 
    NEW_VALUE DECIMAL(12, 2) NULL, 
    NEW_COUNT INTEGER NULL, 
    USED_VALUE DECIMAL(12, 2) NULL, 
    USED_COUNT INTEGER NULL, 
    COLLECTIBLE_VALUE DECIMAL(12, 2) NULL, 
    COLLECTIBLE_COUNT INTEGER NULL, 
    BUYER_WAITING BOOLEAN NULL,
    WEIGHT VARCHAR(32) NULL, 
    SALES_RANK INTEGER NOT NULL, 
    THUMB_IMAGE_COUNT INTEGER NOT NULL,
    FULL_IMAGE_COUNT INTEGER NOT NULL,
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    USER3 VARCHAR(255) NULL, 
    USER4 VARCHAR(255) NULL, 
    USER5 VARCHAR(255) NULL, 
    USER6 VARCHAR(255) NULL, 
    USER7 VARCHAR(255) NULL, 
    USER8 VARCHAR(255) NULL, 
    USER9 VARCHAR(255) NULL, 
    USER10 VARCHAR(255) NULL, 
    USERL1 BIGINT NULL, 
    USERL2 BIGINT NULL, 
    USERL3 BIGINT NULL, 
    USERL4 BIGINT NULL, 
    USERL5 BIGINT NULL, 
    USERL6 BIGINT NULL, 
    USERL7 BIGINT NULL, 
    USERL8 BIGINT NULL, 
    USERL9 BIGINT NULL, 
    USERL10 BIGINT NULL, 
    FILLER1 VARCHAR(255) NULL,  
    FILLER2 VARCHAR(255) NULL, 
    FILLER3 VARCHAR(255) NULL, 
    FILLER4 VARCHAR(255) NULL, 
    FILLER5 VARCHAR(255) NULL, 
    FILLER6 VARCHAR(255) NULL, 
    FILLER7 VARCHAR(255) NULL, 
    FILLER8 VARCHAR(255) NULL, 
    FILLER9 VARCHAR(255) NULL, 
    FILLER10 VARCHAR(255) NULL,  
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Readerware Volumes table
CREATE TABLE READERWARE_VOLUMES (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    BOOK_ID BIGINT NOT NULL,
    VOL_NUMBER INTEGER NOT NULL,
    VOL_TITLE VARCHAR(255) NULL, 
    VOL_USER1 VARCHAR(255), 
    VOL_USER2 VARCHAR(255), 
    VOL_FILLER1 VARCHAR(255) NULL, 
    VOL_FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(BOOK_ID) REFERENCES READERWARE(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Readerware Chapters table
CREATE TABLE READERWARE_CHAPTERS (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    VOL_ID BIGINT NOT NULL,
    CHP_NUMBER INTEGER NOT NULL,
    CHP_TITLE VARCHAR(255) NULL, 
    CHP_AUTHOR BIGINT NULL, 
    CHP_ILLUSTRATOR BIGINT NULL, 
    CHP_TRANSLATOR BIGINT NULL, 
    CHP_EDITOR BIGINT NULL, 
    CHP_MY_RATING BIGINT NULL, 
    CHP_FAVORITE BOOLEAN NOT NULL,
    CHP_READ_COUNT INTEGER NOT NULL,
    CHP_COMMENTS VARCHAR(255) NULL, 
    CHP_MEDIA_URL VARCHAR(255) NULL, 
    CHP_USER1 VARCHAR(255) NULL, 
    CHP_USER2 VARCHAR(255) NULL, 
    CHP_FILLER1 VARCHAR(255) NULL, 
    CHP_FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(VOL_ID) REFERENCES READERWARE_VOLUMES(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Readerware Image tables
CREATE TABLE THUMB_IMAGES (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA BLOB NULL, 
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES READERWARE(ROWKEY)
) AUTO_INCREMENT = 1;

CREATE TABLE FULL_IMAGES (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA MEDIUMBLOB NULL, 
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES READERWARE(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Readerware Contributor table
CREATE TABLE CONTRIBUTOR (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    NAME VARCHAR(128) NOT NULL,
    SORT_NAME VARCHAR(128) NULL,
    ROLE1 INTEGER NULL,
    ROLE2 INTEGER NULL,
    ROLE3 INTEGER NULL,
    BIO TEXT NULL, 
    FAVORITE BOOLEAN NOT NULL,
    BIRTH_DATE DATE NULL, 
    BIRTH_PLACE VARCHAR(128) NULL,
    DEATH_DATE DATE NULL, 
    DEATH_PLACE VARCHAR(128) NULL,
    NOTES TEXT NULL, 
    CONTRIB_URL VARCHAR(255) NULL, 
    IMAGE_DATA BLOB NULL, 
    EXTERNAL_ID VARCHAR(32) NULL, 
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Category table
CREATE TABLE CATEGORY_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Condition table
CREATE TABLE CONDITION_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Publisher table
CREATE TABLE PUBLISHER_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Publication Place table
CREATE TABLE PUBLICATION_PLACE_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Edition table
CREATE TABLE EDITION_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Language table
CREATE TABLE LANGUAGE_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Format table
CREATE TABLE FORMAT_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Signed table
CREATE TABLE SIGNED_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Reading Level table
CREATE TABLE READING_LEVEL_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Type table
CREATE TABLE TYPE_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Location table
CREATE TABLE LOCATION_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the User Rating table
CREATE TABLE MY_RATING_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Series table
CREATE TABLE SERIES_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Source table
CREATE TABLE SOURCE_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Purchase Place table
CREATE TABLE PURCHASE_PLACE_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Owner table
CREATE TABLE OWNER_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Status table
CREATE TABLE STATUS_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the User List table
CREATE TABLE USER_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LIST_NUMBER INTEGER NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Loan table
CREATE TABLE LOANS (
    LN_ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LN_ITEM_ROWKEY BIGINT NOT NULL,
    LN_BRWR_ROWKEY BIGINT NOT NULL,
    LN_ITEM_COPY_ID VARCHAR(255) NULL,
    LN_STATUS INTEGER NULL,
    LN_OUT_DATE DATE NOT NULL, 
    LN_DUE_DATE DATE NULL, 
    LN_IN_DATE DATE NULL, 
    LN_USER1 VARCHAR(255) NULL, 
    LN_USER2 VARCHAR(255) NULL, 
    LN_FILLER1 VARCHAR(255) NULL, 
    LN_FILLER2 VARCHAR(255) NULL,
    PRIMARY KEY(LN_ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Borrower table
CREATE TABLE BORROWER (
    BRWR_ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    BRWR_FNAME VARCHAR(100) NULL,
    BRWR_LNAME VARCHAR(100) NULL,
    BRWR_ID VARCHAR(32) NULL,
    BRWR_STATUS INTEGER NULL,
    BRWR_EMAIL VARCHAR(100) NULL, 
    BRWR_PHONE1 VARCHAR(32) NULL,
    BRWR_PHONE2 VARCHAR(32) NULL,
    BRWR_FAX VARCHAR(32) NULL,
    BRWR_ORG VARCHAR(100) NULL,
    BRWR_ADDR1 VARCHAR(100) NULL,
    BRWR_ADDR2 VARCHAR(100) NULL,
    BRWR_CITY VARCHAR(100) NULL,
    BRWR_STATE VARCHAR(32) NULL,
    BRWR_ZIP VARCHAR(32) NULL,
    BRWR_PATRON_TYPE BIGINT NULL, 
    BRWR_READING_LEVEL BIGINT NULL, 
    BRWR_LEXILE_LEVEL CHAR(14) NULL, 
    BRWR_USER1 VARCHAR(255) NULL, 
    BRWR_USER2 VARCHAR(255) NULL, 
    BRWR_FILLER1 VARCHAR(255) NULL, 
    BRWR_FILLER2 VARCHAR(255) NULL, 
    UNIQUE (BRWR_ID),
    PRIMARY KEY(BRWR_ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Borrower Patron Type table
CREATE TABLE BRWR_PATRON_TYPE_LIST (
    ROWKEY BIGINT AUTO_INCREMENT NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
) AUTO_INCREMENT = 1;


-- Create the Preferences table
CREATE TABLE PREFERENCES (
    PREFS_KEY VARCHAR(128) NOT NULL,
    PREFS_VALUE VARCHAR(4096) NOT NULL,
    PRIMARY KEY(PREFS_KEY)
);
