
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.


-- Internal table
-- Must be present
CREATE TABLE DBCATALOG40 (
    ROWKEY BIGSERIAL,
    EV DATE NOT NULL,
    EV_DESC VARCHAR(255) NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create main Readerware table
CREATE TABLE READERWARE (
    ROWKEY BIGSERIAL,
    TITLE VARCHAR(255) NOT NULL, 
    ALT_TITLE VARCHAR(255), 
    SUBTITLE VARCHAR(255), 
    AUTHOR BIGINT, 
    AUTHOR2 BIGINT,
    AUTHOR3 BIGINT,
    AUTHOR4 BIGINT,
    AUTHOR5 BIGINT,
    AUTHOR6 BIGINT,
    ILLUSTRATOR BIGINT,
    TRANSLATOR BIGINT,
    EDITOR BIGINT,
    PUBLISHER BIGINT, 
    PUB_PLACE BIGINT, 
    RELEASE_DATE DATE, 
    COPYRIGHT_DATE DATE, 
    PAGES INTEGER, 
    EDITION BIGINT, 
    CONTENT_LANGUAGE BIGINT, 
    SIGNED BIGINT, 
    DIMENSIONS VARCHAR(32), 
    READING_LEVEL BIGINT, 
    LEXILE_LEVEL CHAR(14), 
    COPIES INTEGER NOT NULL, 
    BARCODE VARCHAR(128), 
    ISBN CHAR(14), 
    ISSN CHAR(16), 
    LCCN VARCHAR(16), 
    DEWEY VARCHAR(32), 
    CALL_NUMBER VARCHAR(32), 
    USER_NUMBER VARCHAR(32), 
    TYPE BIGINT, 
    FORMAT BIGINT, 
    SERIES BIGINT, 
    SERIES_NUMBER  	DOUBLE PRECISION NOT NULL, 
    MY_RATING BIGINT, 
    ITEM_CONDITION BIGINT, 
    COVER_CONDITION BIGINT, 
    CATEGORY1 BIGINT, 
    CATEGORY2 BIGINT, 
    CATEGORY3 BIGINT, 
    LOCATION BIGINT, 
    KEYWORDS VARCHAR(255), 
    READ_COUNT INTEGER NOT NULL, 
    DATE_LAST_READ DATE, 
    PRODUCT_INFO VARCHAR(65536), 
    MY_COMMENTS VARCHAR(65536), 
    DATE_ENTERED DATE NOT NULL, 
    DATE_LAST_UPDATED DATE NOT NULL, 
    SOURCE BIGINT, 
    PURCHASE_PRICE DECIMAL(12, 2) NOT NULL, 
    PURCHASE_DATE DATE, 
    PURCHASE_PLACE BIGINT, 
    LIST_PRICE DECIMAL(12, 2) NOT NULL, 
    ITEM_VALUE DECIMAL(12, 2) NOT NULL, 
    VALUATION_DATE DATE, 
    CURRENCY_SYMBOL VARCHAR(5), 
    FAVORITE BOOLEAN NOT NULL,
    OUT_OF_PRINT BOOLEAN NOT NULL,
    MEDIA_URL VARCHAR(255), 
    OWNER BIGINT, 
    STATUS BIGINT, 
    EXTERNAL_ID VARCHAR(32), 
    INVENTORY INTEGER NOT NULL,
    IN_LAST_BATCH BOOLEAN NOT NULL,
    AM_ASIN CHAR(14), 
    SALE_PRICE DECIMAL(12, 2), 
    SALE_DATE DATE, 
    NEW_VALUE DECIMAL(12, 2), 
    NEW_COUNT INTEGER, 
    USED_VALUE DECIMAL(12, 2), 
    USED_COUNT INTEGER, 
    COLLECTIBLE_VALUE DECIMAL(12, 2), 
    COLLECTIBLE_COUNT INTEGER, 
    BUYER_WAITING BOOLEAN,
    WEIGHT VARCHAR(32), 
    SALES_RANK INTEGER NOT NULL, 
    THUMB_IMAGE_COUNT INTEGER NOT NULL,
    FULL_IMAGE_COUNT INTEGER NOT NULL,
    USER1 VARCHAR(255), 
    USER2 VARCHAR(255), 
    USER3 VARCHAR(255), 
    USER4 VARCHAR(255), 
    USER5 VARCHAR(255), 
    USER6 VARCHAR(255), 
    USER7 VARCHAR(255), 
    USER8 VARCHAR(255), 
    USER9 VARCHAR(255), 
    USER10 VARCHAR(255), 
    USERL1 BIGINT, 
    USERL2 BIGINT, 
    USERL3 BIGINT, 
    USERL4 BIGINT, 
    USERL5 BIGINT, 
    USERL6 BIGINT, 
    USERL7 BIGINT, 
    USERL8 BIGINT, 
    USERL9 BIGINT, 
    USERL10 BIGINT, 
    FILLER1 VARCHAR(255),  
    FILLER2 VARCHAR(255), 
    FILLER3 VARCHAR(255), 
    FILLER4 VARCHAR(255), 
    FILLER5 VARCHAR(255), 
    FILLER6 VARCHAR(255), 
    FILLER7 VARCHAR(255), 
    FILLER8 VARCHAR(255), 
    FILLER9 VARCHAR(255), 
    FILLER10 VARCHAR(255),  
    PRIMARY KEY(ROWKEY)
);


-- Create the Readerware Volumes table
CREATE TABLE READERWARE_VOLUMES (
    ROWKEY BIGSERIAL,
    BOOK_ID BIGINT NOT NULL,
    VOL_NUMBER INTEGER NOT NULL,
    VOL_TITLE VARCHAR(255), 
    VOL_USER1 VARCHAR(255), 
    VOL_USER2 VARCHAR(255), 
    VOL_FILLER1 VARCHAR(255), 
    VOL_FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(BOOK_ID) REFERENCES READERWARE(ROWKEY)
);


-- Create the Readerware Chapters table
CREATE TABLE READERWARE_CHAPTERS (
    ROWKEY BIGSERIAL,
    VOL_ID BIGINT NOT NULL,
    CHP_NUMBER INTEGER NOT NULL,
    CHP_TITLE VARCHAR(255), 
    CHP_AUTHOR BIGINT, 
    CHP_ILLUSTRATOR BIGINT, 
    CHP_TRANSLATOR BIGINT, 
    CHP_EDITOR BIGINT, 
    CHP_MY_RATING BIGINT, 
    CHP_FAVORITE BOOLEAN NOT NULL,
    CHP_READ_COUNT INTEGER NOT NULL,
    CHP_COMMENTS VARCHAR(255), 
    CHP_MEDIA_URL VARCHAR(255), 
    CHP_USER1 VARCHAR(255), 
    CHP_USER2 VARCHAR(255), 
    CHP_FILLER1 VARCHAR(255), 
    CHP_FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(VOL_ID) REFERENCES READERWARE_VOLUMES(ROWKEY)
);


-- Create the Readerware Image tables
CREATE TABLE THUMB_IMAGES (
    ROWKEY BIGSERIAL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA BYTEA,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES READERWARE(ROWKEY)
);

CREATE TABLE FULL_IMAGES (
    ROWKEY BIGSERIAL,
    ROW_ID BIGINT NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA BYTEA,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    PRIMARY KEY(ROWKEY),
    FOREIGN KEY(ROW_ID) REFERENCES READERWARE(ROWKEY)
);


-- Create the Readerware Contributor table
CREATE TABLE CONTRIBUTOR (
    ROWKEY BIGSERIAL,
    NAME VARCHAR(128) NOT NULL,
    SORT_NAME VARCHAR(128),
    ROLE1 INTEGER,
    ROLE2 INTEGER,
    ROLE3 INTEGER,
    BIO VARCHAR(32768), 
    FAVORITE BOOLEAN NOT NULL,
    BIRTH_DATE DATE, 
    BIRTH_PLACE VARCHAR(128),
    DEATH_DATE DATE, 
    DEATH_PLACE VARCHAR(128),
    NOTES VARCHAR(32768), 
    CONTRIB_URL VARCHAR(255), 
    IMAGE_DATA BYTEA,
    EXTERNAL_ID VARCHAR(32), 
    USER1 VARCHAR(255), 
    USER2 VARCHAR(255), 
    FILLER1 VARCHAR(255), 
    FILLER2 VARCHAR(255), 
    PRIMARY KEY(ROWKEY)
);


-- Create the Publisher table
CREATE TABLE PUBLISHER_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Publication Place table
CREATE TABLE PUBLICATION_PLACE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Edition table
CREATE TABLE EDITION_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Language table
CREATE TABLE LANGUAGE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Signed table
CREATE TABLE SIGNED_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Reading Level table
CREATE TABLE READING_LEVEL_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Type table
CREATE TABLE TYPE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Format table
CREATE TABLE FORMAT_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Series table
CREATE TABLE SERIES_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the User Rating table
CREATE TABLE MY_RATING_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Condition table
CREATE TABLE CONDITION_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Category table
CREATE TABLE CATEGORY_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Location table
CREATE TABLE LOCATION_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Source table
CREATE TABLE SOURCE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Purchase Place table
CREATE TABLE PURCHASE_PLACE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Owner table
CREATE TABLE OWNER_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(128) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Status table
CREATE TABLE STATUS_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the User List table
CREATE TABLE USER_LIST (
    ROWKEY BIGSERIAL,
    LIST_NUMBER INTEGER NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Loan table
CREATE TABLE LOANS (
    LN_ROWKEY BIGSERIAL,
    LN_ITEM_ROWKEY BIGINT NOT NULL,
    LN_BRWR_ROWKEY BIGINT NOT NULL,
    LN_ITEM_COPY_ID VARCHAR(255),
    LN_STATUS INTEGER,
    LN_OUT_DATE DATE NOT NULL, 
    LN_DUE_DATE DATE, 
    LN_IN_DATE DATE, 
    LN_USER1 VARCHAR(255), 
    LN_USER2 VARCHAR(255), 
    LN_FILLER1 VARCHAR(255), 
    LN_FILLER2 VARCHAR(255),
    PRIMARY KEY(LN_ROWKEY)
);


-- Create the Borrower table
CREATE TABLE BORROWER (
    BRWR_ROWKEY BIGSERIAL,
    BRWR_FNAME VARCHAR(100),
    BRWR_LNAME VARCHAR(100),
    BRWR_ID VARCHAR(32),
    BRWR_STATUS INTEGER,
    BRWR_EMAIL VARCHAR(100), 
    BRWR_PHONE1 VARCHAR(32),
    BRWR_PHONE2 VARCHAR(32),
    BRWR_FAX VARCHAR(32),
    BRWR_ORG VARCHAR(100),
    BRWR_ADDR1 VARCHAR(100),
    BRWR_ADDR2 VARCHAR(100),
    BRWR_CITY VARCHAR(100),
    BRWR_STATE VARCHAR(32),
    BRWR_ZIP VARCHAR(32),
    BRWR_PATRON_TYPE BIGINT, 
    BRWR_READING_LEVEL BIGINT, 
    BRWR_LEXILE_LEVEL CHAR(14), 
    BRWR_USER1 VARCHAR(255), 
    BRWR_USER2 VARCHAR(255), 
    BRWR_FILLER1 VARCHAR(255), 
    BRWR_FILLER2 VARCHAR(255), 
    UNIQUE (BRWR_ID),
    PRIMARY KEY(BRWR_ROWKEY)
);


-- Create the Borrower Patron Type table
CREATE TABLE BRWR_PATRON_TYPE_LIST (
    ROWKEY BIGSERIAL,
    LISTITEM VARCHAR(32) NOT NULL,
    PRIMARY KEY(ROWKEY)
);


-- Create the Preferences table
CREATE TABLE PREFERENCES (
    PREFS_KEY VARCHAR(128) NOT NULL,
    PREFS_VALUE VARCHAR(4096) NOT NULL, 
    PRIMARY KEY(PREFS_KEY)
);
