
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.


-- Internal table
-- Must be present
CREATE TABLE DBCATALOG40 (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    EV INTEGER NOT NULL,
    EV_DESC TEXT
);


-- Create main Readerware table
CREATE TABLE READERWARE (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    TITLE TEXT NOT NULL, 
    ALT_TITLE TEXT, 
    SUBTITLE TEXT, 
    AUTHOR INTEGER, 
    AUTHOR2 INTEGER,
    AUTHOR3 INTEGER,
    AUTHOR4 INTEGER,
    AUTHOR5 INTEGER,
    AUTHOR6 INTEGER,
    ILLUSTRATOR INTEGER,
    TRANSLATOR INTEGER,
    EDITOR INTEGER,
    PUBLISHER INTEGER, 
    PUB_PLACE INTEGER, 
    RELEASE_DATE INTEGER, 
    COPYRIGHT_DATE INTEGER, 
    PAGES INTEGER, 
    EDITION INTEGER, 
    CONTENT_LANGUAGE INTEGER, 
    SIGNED INTEGER, 
    DIMENSIONS TEXT, 
    READING_LEVEL INTEGER, 
    LEXILE_LEVEL TEXT, 
    COPIES INTEGER NOT NULL, 
    BARCODE TEXT, 
    ISBN TEXT, 
    ISSN TEXT, 
    LCCN TEXT, 
    DEWEY TEXT, 
    CALL_NUMBER TEXT, 
    USER_NUMBER TEXT, 
    TYPE INTEGER, 
    FORMAT INTEGER, 
    SERIES INTEGER, 
    SERIES_NUMBER NUMERIC NOT NULL, 
    MY_RATING INTEGER, 
    ITEM_CONDITION INTEGER, 
    COVER_CONDITION INTEGER, 
    CATEGORY1 INTEGER, 
    CATEGORY2 INTEGER, 
    CATEGORY3 INTEGER, 
    LOCATION INTEGER, 
    KEYWORDS TEXT, 
    READ_COUNT INTEGER NOT NULL, 
    DATE_LAST_READ INTEGER, 
    PRODUCT_INFO TEXT, 
    MY_COMMENTS TEXT, 
    DATE_ENTERED INTEGER NOT NULL, 
    DATE_LAST_UPDATED INTEGER NOT NULL, 
    SOURCE INTEGER, 
    PURCHASE_PRICE NUMERIC NOT NULL, 
    PURCHASE_DATE INTEGER, 
    PURCHASE_PLACE INTEGER, 
    LIST_PRICE NUMERIC NOT NULL, 
    ITEM_VALUE NUMERIC NOT NULL, 
    VALUATION_DATE INTEGER, 
    CURRENCY_SYMBOL TEXT, 
    FAVORITE INTEGER NOT NULL,
    OUT_OF_PRINT INTEGER NOT NULL,
    MEDIA_URL TEXT, 
    OWNER INTEGER,
    STATUS INTEGER, 
    EXTERNAL_ID TEXT, 
    INVENTORY INTEGER NOT NULL,
    IN_LAST_BATCH INTEGER NOT NULL,
    AM_ASIN TEXT, 
    SALE_PRICE NUMERIC, 
    SALE_DATE INTEGER, 
    NEW_VALUE NUMERIC, 
    NEW_COUNT INTEGER, 
    USED_VALUE NUMERIC, 
    USED_COUNT INTEGER, 
    COLLECTIBLE_VALUE NUMERIC, 
    COLLECTIBLE_COUNT INTEGER, 
    BUYER_WAITING INTEGER,
    WEIGHT TEXT, 
    SALES_RANK INTEGER NOT NULL, 
    THUMB_IMAGE_COUNT INTEGER NOT NULL,
    FULL_IMAGE_COUNT INTEGER NOT NULL,
    USER1 TEXT, 
    USER2 TEXT, 
    USER3 TEXT, 
    USER4 TEXT, 
    USER5 TEXT, 
    USER6 TEXT, 
    USER7 TEXT, 
    USER8 TEXT, 
    USER9 TEXT, 
    USER10 TEXT, 
    USERL1 INTEGER, 
    USERL2 INTEGER, 
    USERL3 INTEGER, 
    USERL4 INTEGER, 
    USERL5 INTEGER, 
    USERL6 INTEGER, 
    USERL7 INTEGER, 
    USERL8 INTEGER, 
    USERL9 INTEGER, 
    USERL10 INTEGER, 
    FILLER1 TEXT,  
    FILLER2 TEXT, 
    FILLER3 TEXT, 
    FILLER4 TEXT, 
    FILLER5 TEXT, 
    FILLER6 TEXT, 
    FILLER7 TEXT, 
    FILLER8 TEXT, 
    FILLER9 TEXT, 
    FILLER10 TEXT
);


-- Create the Readerware Volumes table
CREATE TABLE READERWARE_VOLUMES (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    BOOK_ID INTEGER NOT NULL,
    VOL_NUMBER INTEGER NOT NULL,
    VOL_TITLE TEXT  
    VOL_USER1 TEXT, 
    VOL_USER2 TEXT, 
    VOL_FILLER1 TEXT, 
    VOL_FILLER2 TEXT, 
    FOREIGN KEY(BOOK_ID) REFERENCES READERWARE(ROWKEY)
);


-- Create the Readerware Chapters table
CREATE TABLE READERWARE_CHAPTERS (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    VOL_ID INTEGER NOT NULL,
    CHP_NUMBER INTEGER NOT NULL,
    CHP_TITLE TEXT, 
    CHP_AUTHOR INTEGER, 
    CHP_ILLUSTRATOR INTEGER, 
    CHP_TRANSLATOR INTEGER, 
    CHP_EDITOR INTEGER, 
    CHP_MY_RATING INTEGER, 
    CHP_FAVORITE INTEGER NOT NULL,
    CHP_READ_COUNT INTEGER NOT NULL,
    CHP_COMMENTS TEXT, 
    CHP_MEDIA_URL TEXT, 
    CHP_USER1 TEXT, 
    CHP_USER2 TEXT, 
    CHP_FILLER1 TEXT, 
    CHP_FILLER2 TEXT, 
    FOREIGN KEY(VOL_ID) REFERENCES READERWARE_VOLUMES(ROWKEY)
);


-- Create the Readerware Image tables
CREATE TABLE THUMB_IMAGES (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    ROW_ID INTEGER NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA BLOB, 
    IMAGE_DESC TEXT, 
    FILLER1 TEXT, 
    FILLER2 TEXT, 
    FOREIGN KEY(ROW_ID) REFERENCES READERWARE(ROWKEY)
);

CREATE TABLE FULL_IMAGES (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    ROW_ID INTEGER NOT NULL,
    IMAGE_INDEX INTEGER NOT NULL,
    IMAGE_DATA BLOB, 
    IMAGE_DESC TEXT, 
    FILLER1 TEXT, 
    FILLER2 TEXT, 
    FOREIGN KEY(ROW_ID) REFERENCES READERWARE(ROWKEY)
);


-- Create the Readerware Contributor table
CREATE TABLE CONTRIBUTOR (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    NAME TEXT NOT NULL,
    SORT_NAME TEXT,
    ROLE1 INTEGER,
    ROLE2 INTEGER,
    ROLE3 INTEGER,
    BIO TEXT, 
    FAVORITE INTEGER NOT NULL,
    BIRTH_DATE INTEGER, 
    BIRTH_PLACE TEXT,
    DEATH_DATE INTEGER, 
    DEATH_PLACE TEXT,
    NOTES TEXT, 
    CONTRIB_URL TEXT, 
    IMAGE_DATA BLOB, 
    EXTERNAL_ID TEXT, 
    USER1 TEXT, 
    USER2 TEXT, 
    FILLER1 TEXT, 
    FILLER2 TEXT
);


-- Create the Publisher table
CREATE TABLE PUBLISHER_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Publication Place table
CREATE TABLE PUBLICATION_PLACE_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Edition table
CREATE TABLE EDITION_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Language table
CREATE TABLE LANGUAGE_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Signed table
CREATE TABLE SIGNED_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Reading Level table
CREATE TABLE READING_LEVEL_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Type table
CREATE TABLE TYPE_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Format table
CREATE TABLE FORMAT_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Series table
CREATE TABLE SERIES_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the User Rating table
CREATE TABLE MY_RATING_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Condition table
CREATE TABLE CONDITION_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Category table
CREATE TABLE CATEGORY_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Location table
CREATE TABLE LOCATION_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Source table
CREATE TABLE SOURCE_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Purchase Place table
CREATE TABLE PURCHASE_PLACE_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Owner table
CREATE TABLE OWNER_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Status table
CREATE TABLE STATUS_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the User List table
CREATE TABLE USER_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LIST_NUMBER INTEGER NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Loan table
CREATE TABLE LOANS (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LN_ITEM_ROWKEY BIGINT NOT NULL,
    LN_BRWR_ROWKEY BIGINT NOT NULL,
    LN_ITEM_COPY_ID TEXT,
    LN_STATUS INTEGER,
    LN_OUT_DATE INTEGER NOT NULL, 
    LN_DUE_DATE INTEGER, 
    LN_IN_DATE INTEGER, 
    LN_USER1 TEXT, 
    LN_USER2 TEXT, 
    LN_FILLER1 TEXT, 
    LN_FILLER2 TEXT
);


-- Create the Borrower table
CREATE TABLE BORROWER (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    BRWR_FNAME TEXT,
    BRWR_LNAME TEXT,
    BRWR_ID TEXT UNIQUE,
    BRWR_STATUS INTEGER,
    BRWR_EMAIL TEXT, 
    BRWR_PHONE1 TEXT,
    BRWR_PHONE2 TEXT,
    BRWR_FAX TEXT,
    BRWR_ORG TEXT,
    BRWR_ADDR1 TEXT,
    BRWR_ADDR2 TEXT,
    BRWR_CITY TEXT,
    BRWR_STATE TEXT,
    BRWR_ZIP TEXT,
    BRWR_PATRON_TYPE INTEGER, 
    BRWR_READING_LEVEL INTEGER, 
    BRWR_LEXILE_LEVEL TEXT, 
    BRWR_USER1 TEXT, 
    BRWR_USER2 TEXT, 
    BRWR_FILLER1 TEXT, 
    BRWR_FILLER2 TEXT
);


-- Create the Borrower Patron Type table
CREATE TABLE BRWR_PATRON_TYPE_LIST (
    ROWKEY INTEGER PRIMARY KEY NOT NULL,
    LISTITEM TEXT NOT NULL
);


-- Create the Preferences table
CREATE TABLE PREFERENCES (
    PREFS_KEY TEXT PRIMARY KEY NOT NULL,
    PREFS_VALUE TEXT NOT NULL
);
