
-- IMPORTANT: Uppercase all SQL commands, this avoids internationalization
-- problems. Some database engines upper case the commands and this can fail
-- in some locales like Turkey.

-- Internal table
-- Must be present
CREATE TABLE DBCATALOG40 (
    ROWKEY AUTOINCREMENT NOT NULL PRIMARY KEY,
    EV DATE NOT NULL,
    EV_DESC VARCHAR(255) NULL
);


-- Create main ReaderwareVW table
CREATE TABLE VIDEOWARE (
    ROWKEY AUTOINCREMENT NOT NULL PRIMARY KEY,
    TITLE VARCHAR(255) NOT NULL, 
    ALT_TITLE VARCHAR(255) NULL, 
    PRODUCER INTEGER NULL, 
    DIRECTOR INTEGER NULL, 
    WRITER INTEGER NULL, 
    SCREENWRITER INTEGER NULL,
    PHOTOGRAPHER INTEGER NULL, 
    COMPOSER INTEGER NULL, 
    EDITOR INTEGER NULL, 
    PUBLISHER INTEGER NULL, 
    PUB_PLACE INTEGER NULL, 
    RUNNING_TIME SMALLINT, 
    RELEASE_DATE DATE NULL, 
    COPYRIGHT_DATE DATE NULL, 
    REGION INTEGER NULL, 
    CERTIFICATION INTEGER NULL, 
    ASPECT_RATIO INTEGER NULL, 
    ANAMORPHIC BIT NOT NULL,
    SUBTITLED BIT NOT NULL,
    CLOSED_CAP BIT NOT NULL, 
    CONTENT_LANGUAGE INTEGER NULL, 
    SOUND INTEGER NULL, 
    COLOR INTEGER NULL, 
    BOOK VARCHAR(255) NULL, 
    AUTHOR INTEGER NULL, 
    COPIES SMALLINT NOT NULL, 
    BARCODE CHAR(128) NULL, 
    UPC CHAR(25) NULL, 
    ISBN CHAR(14) NULL, 
    LCCN VARCHAR(16) NULL, 
    DEWEY VARCHAR(32) NULL, 
    CALL_NUMBER VARCHAR(32) NULL, 
    USER_NUMBER VARCHAR(32) NULL, 
    TYPE INTEGER NULL, 
    FORMAT INTEGER NULL, 
    SERIES INTEGER NULL, 
    MY_RATING INTEGER NULL, 
    TRANSFER_RATING INTEGER NULL, 
    ITEM_CONDITION INTEGER NULL, 
    COVER_CONDITION INTEGER NULL, 
    CATEGORY1 INTEGER NULL, 
    CATEGORY2 INTEGER NULL, 
    CATEGORY3 INTEGER NULL, 
    LOCATION INTEGER NULL, 
    KEYWORDS VARCHAR(255) NULL, 
    PLAYED_COUNT SMALLINT NOT NULL, 
    DATE_LAST_PLAYED DATE NULL, 
    PLAYLIST BIT NOT NULL,
    PRODUCT_INFO MEMO NULL, 
    MY_COMMENTS MEMO NULL, 
    EXTRAS_INFO MEMO NULL, 
    DATE_ENTERED DATE NOT NULL, 
    DATE_LAST_UPDATED DATE NOT NULL, 
    SOURCE INTEGER, 
    PURCHASE_PRICE CURRENCY NOT NULL, 
    PURCHASE_DATE DATE NULL, 
    PURCHASE_PLACE INTEGER NULL, 
    LIST_PRICE CURRENCY NOT NULL, 
    ITEM_VALUE CURRENCY NOT NULL, 
    VALUATION_DATE DATE NULL, 
    CURRENCY_SYMBOL VARCHAR(5) NULL, 
    FAVORITE BIT NOT NULL,
    OUT_OF_PRINT BIT NOT NULL,
    MEDIA_URL VARCHAR(255) NULL, 
    OWNER INTEGER NULL, 
    STATUS INTEGER NULL, 
    EXTERNAL_ID VARCHAR(32) NULL, 
    INVENTORY SMALLINT NOT NULL,
    IN_LAST_BATCH BIT NOT NULL,
    AM_ASIN CHAR(14) NULL, 
    SALE_PRICE CURRENCY NULL, 
    SALE_DATE DATE NULL, 
    NEW_VALUE CURRENCY NULL, 
    NEW_COUNT SMALLINT NULL, 
    USED_VALUE CURRENCY NULL, 
    USED_COUNT SMALLINT NULL, 
    COLLECTIBLE_VALUE CURRENCY NULL, 
    COLLECTIBLE_COUNT SMALLINT NULL, 
    BUYER_WAITING BIT NULL,
    WEIGHT VARCHAR(32) NULL, 
    SALES_RANK INTEGER NOT NULL, 
    THUMB_IMAGE_COUNT INTEGER NOT NULL,
    FULL_IMAGE_COUNT INTEGER NOT NULL,
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    USER3 VARCHAR(255) NULL, 
    USER4 VARCHAR(255) NULL, 
    USER5 VARCHAR(255) NULL, 
    USER6 VARCHAR(255) NULL, 
    USER7 VARCHAR(255) NULL, 
    USER8 VARCHAR(255) NULL, 
    USER9 VARCHAR(255) NULL, 
    USER10 VARCHAR(255) NULL, 
    USERL1 INTEGER NULL, 
    USERL2 INTEGER NULL, 
    USERL3 INTEGER NULL, 
    USERL4 INTEGER NULL, 
    USERL5 INTEGER NULL, 
    USERL6 INTEGER NULL, 
    USERL7 INTEGER NULL, 
    USERL8 INTEGER NULL, 
    USERL9 INTEGER NULL, 
    USERL10 INTEGER NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
    FILLER3 VARCHAR(255) NULL, 
    FILLER4 VARCHAR(255) NULL, 
    FILLER5 VARCHAR(255) NULL, 
    FILLER6 VARCHAR(255) NULL, 
    FILLER7 VARCHAR(255) NULL, 
    FILLER8 VARCHAR(255) NULL, 
    FILLER9 VARCHAR(255) NULL, 
    FILLER10 VARCHAR(255) NULL
);


-- Create the ReaderwareVW Actor link table
CREATE TABLE VIDEOWARE_ACTORS (
    ACT_TITLE_ID INTEGER NOT NULL REFERENCES VIDEOWARE(ROWKEY),
    ACT_ACTOR_ID INTEGER NOT NULL,
    ACT_ACTOR_POSITION SMALLINT NOT NULL
);


-- Create the ReaderwareVW Disks table
CREATE TABLE VIDEOWARE_DISKS (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    VIDEO_ID INTEGER NOT NULL REFERENCES VIDEOWARE(ROWKEY),
    DISK_NUMBER SMALLINT NOT NULL,
    DISK_TITLE VARCHAR(255) NULL, 
    DISK_SIDE_BREAK SMALLINT NOT NULL,
    DISK_UNIT_NUMBER SMALLINT NULL,
    DISK_SLOT_NUMBER SMALLINT NULL,
    DISK_RUNNING_TIME SMALLINT NULL, 
    DISK_USER1 VARCHAR(255), 
    DISK_USER2 VARCHAR(255), 
    DISK_FILLER1 VARCHAR(255) NULL, 
    DISK_FILLER2 VARCHAR(255) NULL
);


-- Create the ReaderwareVW Episodes table
CREATE TABLE VIDEOWARE_EPISODES (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    DISK_ID INTEGER NOT NULL REFERENCES VIDEOWARE_DISKS(ROWKEY),
    EP_NUMBER SMALLINT NOT NULL,
    EP_TITLE VARCHAR(255) NULL, 
    EP_ACTOR1 INTEGER NULL, 
    EP_ACTOR2 INTEGER NULL, 
    EP_ACTOR3 INTEGER NULL, 
    EP_ACTOR4 INTEGER NULL, 
    EP_ACTOR5 INTEGER NULL, 
    EP_ACTOR6 INTEGER NULL, 
    EP_ACTOR7 INTEGER NULL, 
    EP_ACTOR8 INTEGER NULL, 
    EP_ACTOR9 INTEGER NULL, 
    EP_ACTOR10 INTEGER NULL, 
    EP_PRODUCER INTEGER NULL, 
    EP_DIRECTOR INTEGER NULL, 
    EP_WRITER INTEGER NULL, 
    EP_SCREENWRITER INTEGER NULL,
    EP_PHOTOGRAPHER INTEGER NULL, 
    EP_COMPOSER INTEGER NULL, 
    EP_EDITOR INTEGER NULL, 
    EP_AUTHOR INTEGER NULL, 
    EP_BOOK VARCHAR(255) NULL, 
    EP_ARTIST INTEGER NULL, 
    EP_CONDUCTOR INTEGER  NULL, 
    EP_ORCHESTRA INTEGER NULL, 
    EP_SOLOIST INTEGER NULL, 
    EP_WORK_TITLE VARCHAR(255) NULL, 
    EP_SONGWRITER VARCHAR(75) NULL,
    EP_RUNNING_TIME SMALLINT NULL, 
    EP_MY_RATING INTEGER NULL, 
    EP_FAVORITE BIT NOT NULL,
    EP_PLAYLIST BIT NOT NULL,
    EP_PLAYED_COUNT SMALLINT NOT NULL,
    EP_COMMENTS VARCHAR(255), 
    EP_MEDIA_URL VARCHAR(255), 
    EP_USER1 VARCHAR(255), 
    EP_USER2 VARCHAR(255), 
    EP_FILLER1 VARCHAR(255) NULL, 
    EP_FILLER2 VARCHAR(255) NULL
);


-- Create the Readerware Image tables
CREATE TABLE THUMB_IMAGES (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    ROW_ID INTEGER NOT NULL REFERENCES VIDEOWARE(ROWKEY),
    IMAGE_INDEX SMALLINT NOT NULL,
    IMAGE_DATA IMAGE NULL,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
);

CREATE TABLE FULL_IMAGES (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    ROW_ID INTEGER NOT NULL REFERENCES VIDEOWARE(ROWKEY),
    IMAGE_INDEX SMALLINT NOT NULL,
    IMAGE_DATA IMAGE NULL,
    IMAGE_DESC VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL, 
);


-- Create the ReaderwareVW Contributor table
CREATE TABLE CONTRIBUTOR (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    NAME VARCHAR(128) NOT NULL,
    SORT_NAME VARCHAR(128) NULL,
    ROLE1 SMALLINT NULL,
    ROLE2 SMALLINT NULL,
    ROLE3 SMALLINT NULL,
    BIO MEMO NULL, 
    FAVORITE BIT NOT NULL,
    BIRTH_DATE DATE NULL, 
    BIRTH_PLACE VARCHAR(128) NULL,
    DEATH_DATE DATE NULL, 
    DEATH_PLACE VARCHAR(128) NULL,
    NOTES MEMO NULL, 
    CONTRIB_URL VARCHAR(255) NULL, 
    IMAGE_DATA IMAGE NULL, 
    EXTERNAL_ID VARCHAR(32) NULL, 
    USER1 VARCHAR(255) NULL, 
    USER2 VARCHAR(255) NULL, 
    FILLER1 VARCHAR(255) NULL, 
    FILLER2 VARCHAR(255) NULL
);


-- Create the Category table
CREATE TABLE CATEGORY_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Color table
CREATE TABLE COLOR_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Condition table
CREATE TABLE CONDITION_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Publisher table
CREATE TABLE PUBLISHER_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Publication Place table
CREATE TABLE PUBLICATION_PLACE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Language table
CREATE TABLE LANGUAGE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Type table
CREATE TABLE TYPE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Format table
CREATE TABLE FORMAT_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Region table
CREATE TABLE REGION_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(75) NOT NULL
);


-- Create the Location table
CREATE TABLE LOCATION_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Industry Rating table
CREATE TABLE CERTIFICATION_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);

-- Create the Aspect Ratio table
CREATE TABLE ASPECT_RATIO_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the User Rating table
CREATE TABLE MY_RATING_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Transfer Rating table
CREATE TABLE TRANSFER_RATING_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Series table
CREATE TABLE SERIES_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Sound table
CREATE TABLE SOUND_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Source table
CREATE TABLE SOURCE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Purchase Place table
CREATE TABLE PURCHASE_PLACE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Owner table
CREATE TABLE OWNER_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(128) NOT NULL
);


-- Create the Status table
CREATE TABLE STATUS_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the User List table
CREATE TABLE USER_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LIST_NUMBER SMALLINT NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Loan table
CREATE TABLE LOANS (
    LN_ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LN_ITEM_ROWKEY INTEGER NOT NULL,
    LN_BRWR_ROWKEY INTEGER NOT NULL,
    LN_ITEM_COPY_ID VARCHAR(255) NULL,
    LN_STATUS SMALLINT NULL,
    LN_OUT_DATE DATE NOT NULL, 
    LN_DUE_DATE DATE NULL, 
    LN_IN_DATE DATE NULL, 
    LN_USER1 VARCHAR(255) NULL, 
    LN_USER2 VARCHAR(255) NULL, 
    LN_FILLER1 VARCHAR(255) NULL, 
    LN_FILLER2 VARCHAR(255) NULL
);


-- Create the Borrower table
CREATE TABLE BORROWER (
    BRWR_ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    BRWR_FNAME VARCHAR(100) NULL,
    BRWR_LNAME VARCHAR(100) NULL,
    BRWR_ID VARCHAR(32) NULL,
    BRWR_STATUS SMALLINT NULL,
    BRWR_EMAIL VARCHAR(100) NULL, 
    BRWR_PHONE1 VARCHAR(32) NULL,
    BRWR_PHONE2 VARCHAR(32) NULL,
    BRWR_FAX VARCHAR(32) NULL,
    BRWR_ORG VARCHAR(100) NULL,
    BRWR_ADDR1 VARCHAR(100) NULL,
    BRWR_ADDR2 VARCHAR(100) NULL,
    BRWR_CITY VARCHAR(100) NULL,
    BRWR_STATE VARCHAR(32) NULL,
    BRWR_ZIP VARCHAR(32) NULL,
    BRWR_USER1 VARCHAR(255) NULL, 
    BRWR_USER2 VARCHAR(255) NULL, 
    BRWR_FILLER1 VARCHAR(255) NULL, 
    BRWR_FILLER2 VARCHAR(255) NULL, 
    UNIQUE (BRWR_ID)
);


-- Create the Borrower Patron Type table
CREATE TABLE BRWR_PATRON_TYPE_LIST (
    ROWKEY AUTOINCREMENT PRIMARY KEY NOT NULL,
    LISTITEM VARCHAR(32) NOT NULL
);


-- Create the Preferences table
CREATE TABLE PREFERENCES (
    PREFS_KEY VARCHAR(128) PRIMARY KEY NOT NULL,
    PREFS_VALUE VARCHAR(4096) NOT NULL
);
